<?php

/**
 * The PHP code for setup Theme page custom fields.
 *
 * @package WordPress
 * @subpackage Pai
 */


/*
	Begin creating custom fields
*/

//Get all sidebars
$theme_sidebar = array(
	'' => '',
	'Page Sidebar' => 'Page Sidebar', 
	'Contact Sidebar' => 'Contact Sidebar', 
	'Blog Sidebar' => 'Blog Sidebar',
);

$dynamic_sidebar = get_option('pp_sidebar');

if(!empty($dynamic_sidebar))
{
	foreach($dynamic_sidebar as $sidebar)
	{
		$theme_sidebar[$sidebar] = $sidebar;
	}
}

/*
	Get gallery list
*/
$args = array(
    'numberposts' => -1,
    'post_type' => array('galleries'),
);

$galleries_arr = get_posts($args);
$galleries_select = array();
$galleries_select['(Display Post Featured Image)'] = '';

foreach($galleries_arr as $gallery)
{
	$galleries_select[$gallery->ID] = $gallery->post_title;
}

/*
	Get all menus available
*/
$menus = get_terms('nav_menu');
$menus_select = array(
	'' => '---- Default Menu ----'
);
foreach($menus as $each_menu)
{
	$menus_select[$each_menu->slug] = $each_menu->name;
}

//Get all footer posts
$args = array(
	 'post_type'     => 'footer',
	 'post_status'   => array( 'publish' ),
	 'numberposts'   => -1,
	 'orderby'       => 'title',
	 'order'         => 'ASC',
	 'suppress_filters'   => false
);
$footers = get_posts($args);
$tg_footers_select = array();
$tg_footers_select[''] = '---- Default Footer ----';

if(!empty($footers))
{
	foreach ($footers as $footer)
	{
		$tg_footers_select[$footer->ID] = $footer->post_title;
	}
}

//Get all header posts
$args = array(
	 'post_type'     => 'header',
	 'post_status'   => array( 'publish' ),
	 'numberposts'   => -1,
	 'orderby'       => 'title',
	 'order'         => 'ASC',
	 'suppress_filters'   => false
);
$headers = get_posts($args);
$tg_headers_select = array();
$tg_headers_select[''] = '---- Default Header ----';

if(!empty($headers))
{
	foreach ($headers as $header)
	{
		$tg_headers_select[$header->ID] = $header->post_title;
	}
}

//Get all fullscreen menu posts
$args = array(
	 'post_type'     => 'fullmenu',
	 'post_status'   => array( 'publish' ),
	 'numberposts'   => -1,
	 'orderby'       => 'title',
	 'order'         => 'ASC',
	 'suppress_filters'   => false
);
$fullmenus = get_posts($args);
$tg_fullmenus_select = array();
$tg_fullmenus_select[''] = '---- Default Menu ----';

if(!empty($fullmenus))
{
	foreach ($fullmenus as $fullmenu)
	{
		$tg_fullmenus_select[$fullmenu->ID] = $fullmenu->post_title;
	}
}

$photography_page_postmetas = array();
$pp_menu_layout = get_option('pp_menu_layout');
	
if($pp_menu_layout != 'leftmenu')
{
    $photography_page_postmetas[99] = array("section" => "Page Menu", "id" => "page_menu_transparent", "type" => "checkbox", "title" => "Make Menu Transparent", "description" => "Check this option if you want to display main menu in transparent");
}

$photography_page_postmetas_extended = 
	array (
		/*
			Begin Page custom fields
		*/
		
		array("section" => "Page Title", "id" => "page_show_title", "type" => "checkbox", "title" => "Hide Default Page Header", "description" => "Check this option if you want to hide default page header"),
		
		array("section" => "Page Tagline", "id" => "page_tagline", "type" => "textarea", "title" => "Page Tagline (Optional)", "description" => "Enter page tagline. It will displays under page title (*Note: HTML code also support)"),
		
		array("section" => "Select Sidebar (Optional)", "id" => "page_sidebar", "type" => "select", "title" => "Page Sidebar (Optional)", "description" => "Select this page's sidebar to display.<br/><br/><strong>NOTE: to use this option, you have to select page template end with \"...Sidebar\" only</strong>", "items" => $theme_sidebar),
		
		array("section" => "Content Type", "id" => "page_gallery_id", "type" => "select", "title" => "Gallery", "description" => "You can select image gallery to display on this page. <strong>(If you select Gallery as page template)</strong>", "items" => $galleries_select),
		
		array("section" => "Vimeo Video ID", "id" => "page_ft_vimeo", "type" => "text", "title" => "Vimeo Video ID", "description" => "Please enter Vimeo Video ID for example 73317780 (*Note enter if you select \"Vimeo Video\" as Featured Content Type)"),
			
		array("section" => "Youtube Video ID", "id" => "page_ft_youtube", "type" => "text", "title" => "Youtube Video ID", "description" => "Please enter Youtube Video ID for example 6AIdXisPqHc (*Note enter if you select \"Youtube Video\" as Featured Content Type)"),
	);
	
	//Check if use default header
	$photography_header_content = get_theme_mod('photography_header_content', 'menu');
	if($photography_header_content == 'menu') {
		$photography_page_postmetas_extended[] = array("section" => "Select Menu", "id" => "page_menu", "type" => "select", "title" => "Page Menu (Optional)", "description" => "Select this page's menu if you want to display main menu other than default one", "items" => $menus_select);
	}
	elseif($photography_header_content == 'content') {
		$photography_page_postmetas_extended[] = array("section" => esc_html__('Select Header (Optional)', 'photography' ), "id" => "page_header", "type" => "select", "title" => esc_html__('Page Header (Optional)', 'photography' ), "description" => esc_html__('Select this page header content if you want to display header content other than default one', 'photography' ), "items" => $tg_headers_select);
		
		$photography_page_postmetas_extended[] = array("section" => esc_html__('Select Sticky Header (Optional)', 'photography' ), "id" => "page_sticky_header", "type" => "select", "title" => esc_html__('Page Sticky Header (Optional)', 'photography' ), "description" => esc_html__('Select this page sticky header content if you want to display header content other than default one', 'photography' ), "items" => $tg_headers_select);
		
		$photography_page_postmetas_extended[] = array("section" => esc_html__('Hide Sticky Header (Optional)', 'photography' ), "id" => "page_hide_sticky_header", "type" => "checkbox", "title" => esc_html__('Hide Sticky Header (Optional)', 'photography' ), "description" => esc_html__('Check this option if you want to hide sticky header on this page', 'photography' ));
		
		$photography_page_postmetas_extended[] = array("section" => esc_html__('Select Transparent Header (Optional)', 'photography' ), "id" => "page_transparent_header", "type" => "select", "title" => esc_html__('Page Transparent Header (Optional)', 'photography' ), "description" => esc_html__('Select this page transparent header content if you want to display transparent header content other than default one', 'photography' ), "items" => $tg_headers_select);
	}
	
	$photography_page_postmetas_extended[] =  array("section" => esc_html__('Select Fullscreen Menu (Optional)', 'grandconference' ), "id" => "page_fullmenu", "type" => "select", "title" => esc_html__('Fullscreen Menu (Optional)', 'grandconference' ), "description" => esc_html__('Select this page fullscreen menu content if you want to display fullscreen menu other than default one', 'grandconference' ), "items" => $tg_fullmenus_select);
	
	$photography_page_postmetas_extended[] =  array("section" => esc_html__('Side Mobile Menu (Optional)', 'grandconference' ), "id" => "page_sidemenu", "type" => "select", "title" => esc_html__('Side Mobile Menu (Optional)', 'grandconference' ), "description" => esc_html__('Select this page mobile menu if you want to display mobile menu other than default one', 'grandconference' ), "items" => $menus_select);
	
	//Check if use default footer
	$photography_footer_content = get_theme_mod('photography_footer_content', 'sidebar');
	if($photography_header_content == 'content') {
		$photography_page_postmetas_extended[] = array("section" => esc_html__('Select Footer (Optional)', 'photography' ), "id" => "page_footer", "type" => "select", "title" => esc_html__('Page Footer (Optional)', 'photography' ), "description" => esc_html__('Select this page footer content if you want to display footer content other than default one', 'photography' ), "items" => $tg_footers_select);
		
		$photography_page_postmetas_extended[] = array("section" => esc_html__('Footer', 'photography' ), "id" => "page_hide_footer", "type" => "checkbox", "title" => esc_html__('Hide Footer', 'photography' ), "description" => esc_html__('Check this option if you want to hide default page footer', 'photography' ));
	}
	


$photography_page_postmetas = $photography_page_postmetas + $photography_page_postmetas_extended;
?>
<?php

function photography_page_create_meta_box() {

	global $photography_page_postmetas;
	if ( function_exists('add_meta_box') && isset($photography_page_postmetas) && count($photography_page_postmetas) > 0 ) {  
		add_meta_box( 'page_metabox', 'Page Options', 'photography_page_new_meta_box', 'page', 'side', 'high' );  
	}

}  

function photography_page_new_meta_box() {
	global $post, $photography_page_postmetas;

	echo '<input type="hidden" name="pp_meta_form" id="pp_meta_form" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
	$meta_section = '';

	foreach ( $photography_page_postmetas as $key => $postmeta ) {

		$meta_id = $postmeta['id'];
		$meta_title = $postmeta['title'];
		$meta_description = $postmeta['description'];
		$meta_section = $postmeta['section'];
		
		$meta_type = '';
		if(isset($postmeta['type']))
		{
			$meta_type = $postmeta['type'];
		}
		
		echo '<div id="page_option_'.strtolower($postmeta['id']).'">';
		
		if($key > 0)
		{
			echo '<br/>';
		}
		
		echo "<strong>".$meta_title."</strong><hr class='pp_widget_hr'/>";
		echo "<div class='pp_widget_description'>$meta_description</div>";

		if ($meta_type == 'checkbox') {
			$checked = get_post_meta($post->ID, $meta_id, true) == '1' ? "checked" : "";
			echo "<br style='clear:both'><input type='checkbox' name='$meta_id' id='$meta_id' class='iphone_checkboxes' value='1' $checked /><br style='clear:both'/>";
		}
		else if ($meta_type == 'select') {
			echo "<p><select name='$meta_id' id='$meta_id'>";
			
			if(!empty($postmeta['items']))
			{
				foreach ($postmeta['items'] as $key => $item)
				{
					$page_style = get_post_meta($post->ID, $meta_id);
				
					if(isset($page_style[0]) && $key == $page_style[0])
					{
						$css_string = 'selected';
					}
					else
					{
						$css_string = '';
					}
				
					echo '<option value="'.$key.'" '.$css_string.'>'.$item.'</option>';
				}
			}
			
			echo "</select></p>";
		}
		else if ($meta_type == 'file') { 
		    echo "<p><input type='text' name='$meta_id' id='$meta_id' class='' value='".get_post_meta($post->ID, $meta_id, true)."' style='width:99%' /><input id='".$meta_id."_button' name='".$meta_id."_button' type='button' value='Upload' class='metabox_upload_btn button' readonly='readonly' rel='".$meta_id."' style='margin:7px 0 0 5px' /></p>";
		}
		else if ($meta_type == 'textarea') { 
			echo "<p><textarea name='$meta_id' id='$meta_id' class='' style='width:99%' rows='5'>".get_post_meta($post->ID, $meta_id, true)."</textarea></p>";
		}
		else {
			echo "<p><input type='text' name='$meta_id' id='$meta_id' class='' value='".get_post_meta($post->ID, $meta_id, true)."' style='width:99%' /></p>";
		}
		
		echo '</div>';
	}
	
	echo '<br/>';

}

function photography_page_save_postdata( $post_id ) {

	global $photography_page_postmetas;

	// verify this came from the our screen and with proper authorization,
	// because save_post can be triggered at other times

	if ( isset($_POST['pp_meta_form']) && !wp_verify_nonce( $_POST['pp_meta_form'], plugin_basename(__FILE__) )) {
		return $post_id;
	}

	// verify if this is an auto save routine. If it is our form has not been submitted, so we dont want to do anything

	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;

	// Check permissions

	if ( isset($_POST['post_type']) && 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return $post_id;
		} else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;
	}

	// OK, we're authenticated

	if ( $parent_id = wp_is_post_revision($post_id) )
	{
		$post_id = $parent_id;
	}
	
	if (isset($_POST['pp_meta_form'])) 
	{
		//If import page content builder
		if(is_admin() && isset($_POST['ppb_import_current']) && !empty($_POST['ppb_import_current']))
		{
			//If upload import builder file
			if(isset($_FILES['ppb_import_current_file']['name']) && !empty($_FILES['ppb_import_current_file']['name']))
			{
				//Check if zip file
				$import_filename = $_FILES['ppb_import_current_file']['name'];
				$import_type = $_FILES['ppb_import_current_file']['type'];
				$is_zip = FALSE;
				$new_filename = basename($import_filename, '_.zip');
				
				$accepted_types = array('application/zip', 
	                                'application/x-zip-compressed', 
	                                'multipart/x-zip', 
	                                'application/s-compressed');
	 
			    foreach($accepted_types as $mime_type) {
			        if($mime_type == $import_type) {
			            $is_zip = TRUE;
			            break;
			        } 
			    }
			}
			//If import demo pages
			else if(isset($_POST['ppb_import_demo_file']) && !empty($_POST['ppb_import_demo_file']))
			{
				$is_zip = FALSE;
			}
			//If import from saved template
			else if(isset($_POST['ppb_import_template_key']) && !empty($_POST['ppb_import_template_key']))
			{
				$is_zip = FALSE;
			}
			
			WP_Filesystem();
			
			if($is_zip)
			{
				$upload_dir = wp_upload_dir();
				$cache_dir = '';
				
				if(isset($upload_dir['basedir']))
				{
					$cache_dir = $upload_dir['basedir'].'/meteors';
				}
				
				move_uploaded_file($_FILES["ppb_import_current_file"]["tmp_name"], $cache_dir.'/'.$import_filename);
				//$unzipfile = unzip_file( $cache_dir.'/'.$import_filename, $cache_dir);
				
				$zip = new ZipArchive();
				$x = $zip->open($cache_dir.'/'.$import_filename);
				
				for($i = 0; $i < $zip->numFiles; $i++) {
			        $new_filename = $zip->getNameIndex($i);
			        break;
			    }  
				
				if ($x === true) {
					$zip->extractTo($cache_dir); 
					$zip->close();
				}

				global $wp_filesystem;
				$import_options_json = $wp_filesystem->get_contents($cache_dir.'/'.$new_filename);
				
				if(empty($import_options_json))
				{
				    $import_options_json = file_get_contents($cache_dir.'/'.$new_filename);
				}
				
				unlink($cache_dir.'/'.$import_filename);
				unlink($cache_dir.'/'.$new_filename);
			}
			else
			{
				global $wp_filesystem;
			
				//If import demo pages
				if(isset($_POST['ppb_import_demo_file']) && !empty($_POST['ppb_import_demo_file']))
				{
					$import_options_json = $wp_filesystem->get_contents(get_template_directory().'/cache/demos/pages/'.$_POST['ppb_import_demo_file']);
					
					if(empty($import_options_json))
					{
						$import_options_json = file_get_contents(get_template_directory().'/cache/demos/pages/'.$_POST['ppb_import_demo_file']);
					}
				}
				//If import from saved template
				else if(isset($_POST['ppb_import_template_key']) && !empty($_POST['ppb_import_template_key']))
				{
					$import_options_json = get_option( SHORTNAME."_template_".$_POST['ppb_import_template_key']);
				}
				//If upload import builder file
				else
				{
					//If .json file then import
					$import_options_json = $wp_filesystem->get_contents($_FILES["ppb_import_current_file"]["tmp_name"]);
					
					if(empty($import_options_json))
					{
						$import_options_json = file_get_contents($_FILES["ppb_import_current_file"]["tmp_name"]);
					}
				}
			}
			
			//Decode JSON content
			$import_options_arr = json_decode($import_options_json, true);
			
			if(isset($import_options_arr['ppb_form_data_order'][0]) && !empty($import_options_arr['ppb_form_data_order'][0]))
			{
				photography_page_update_custom_meta($post_id, $import_options_arr['ppb_form_data_order'][0], 'ppb_form_data_order');
			}
			
			$ppb_item_arr = explode(',', $import_options_arr['ppb_form_data_order'][0]);
			
			if(is_array($ppb_item_arr) && !empty($ppb_item_arr))
			{
				foreach($ppb_item_arr as $key => $ppb_item_arr)
				{
					if(isset($import_options_arr[$ppb_item_arr.'_data'][0]) && !empty($import_options_arr[$ppb_item_arr.'_data'][0]))
					{
						photography_page_update_custom_meta($post_id, $import_options_arr[$ppb_item_arr.'_data'][0], $ppb_item_arr.'_data');
					}
					
					if(isset($import_options_arr[$ppb_item_arr.'_size'][0]) && !empty($import_options_arr[$ppb_item_arr.'_size'][0]))
					{
						photography_page_update_custom_meta($post_id, $import_options_arr[$ppb_item_arr.'_size'][0], $ppb_item_arr.'_size');
					}
				}
			}
			
			$refresh_url = '';
			if(isset($_POST['ppb_edit_mode']) && $_POST['ppb_edit_mode'] == 'live')
			{
				$refresh_url.= '&ppb_mode=live';
			}
			
			header("Location: ".$_SERVER['HTTP_REFERER'].$refresh_url);
			exit;
		}
	
		//If export page content builder
		if(is_admin() && isset($_POST['ppb_export_current']) && !empty($_POST['ppb_export_current']))
		{
			$page_title = get_the_title($post_id);
		
			$json_file_name = $post_id;
	
			header('Content-disposition: attachment; filename='.$json_file_name.'.json');
			header('Content-type: application/json');
			
			//Get current content builder data
			$ppb_form_data_order = get_post_meta($post_id, 'ppb_form_data_order');
			$export_options_arr = array();
			
			if(!empty($ppb_form_data_order))
			{
				$export_options_arr['ppb_form_data_order'] = $ppb_form_data_order;

				//Get each builder module data
				$ppb_form_item_arr = explode(',', $ppb_form_data_order[0]);
			
				foreach($ppb_form_item_arr as $key => $ppb_form_item)
				{
					$ppb_form_item_data = get_post_meta($post_id, $ppb_form_item.'_data');
					$export_options_arr[$ppb_form_item.'_data'] = $ppb_form_item_data;
					
					$ppb_form_item_size = get_post_meta($post_id, $ppb_form_item.'_size');
					$export_options_arr[$ppb_form_item.'_size'] = $ppb_form_item_size;
				}
			}
		
			echo json_encode($export_options_arr);
			
			exit;
		}
	
		foreach ( $photography_page_postmetas as $postmeta ) 
		{
		
			if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']]) {
				photography_page_update_custom_meta($post_id, $_POST[$postmeta['id']], $postmeta['id']);
			}
	
			if (isset($_POST[$postmeta['id']]) && $_POST[$postmeta['id']] == "") {
				delete_post_meta($post_id, $postmeta['id']);
			}
			
			if (!isset($_POST[$postmeta['id']])) {
				delete_post_meta($post_id, $postmeta['id']);
			}
		}
		
		// Saving Page Builder Data
		if(isset($_POST['ppb_enable']) && !empty($_POST['ppb_enable']))
		{
			photography_page_update_custom_meta($post_id, $_POST['ppb_enable'], 'ppb_enable');
		}
		else
		{
			delete_post_meta($post_id, 'ppb_enable');
		}

		if(isset($_POST['ppb_form_data_order']) && !empty($_POST['ppb_form_data_order']))
		{
			photography_page_update_custom_meta($post_id, $_POST['ppb_form_data_order'], 'ppb_form_data_order');
			
			$ppb_item_arr = explode(',', $_POST['ppb_form_data_order']);
			if(is_array($ppb_item_arr) && !empty($ppb_item_arr))
			{
				foreach($ppb_item_arr as $key => $ppb_item_arr)
				{
					if(isset($_POST[$ppb_item_arr.'_data']) && !empty($_POST[$ppb_item_arr.'_data']))
					{
						photography_page_update_custom_meta($post_id, $_POST[$ppb_item_arr.'_data'], $ppb_item_arr.'_data');
					}
					
					if(isset($_POST[$ppb_item_arr.'_size']) && !empty($_POST[$ppb_item_arr.'_size']))
					{
						photography_page_update_custom_meta($post_id, $_POST[$ppb_item_arr.'_size'], $ppb_item_arr.'_size');
					}
				}
			}
		}
		//If content builder is empty
		else if(isset($_POST['ppb_remove_all']) && !empty($_POST['ppb_remove_all']))
		{
			photography_page_update_custom_meta($post_id, '', 'ppb_form_data_order');
		}
	}
	
	//If enable Content Builder then also copy its content to standard page content
	if (isset($_POST['ppb_enable']) && !empty($_POST['ppb_enable']) && ! wp_is_post_revision( $post_id ) )
	{
		//unhook this function so it doesn't loop infinitely
		remove_action('save_post', 'photography_page_save_postdata');
	
		//update the post, which calls save_post again
		$ppb_page_content = photography_apply_builder($post_id, 'page', FALSE);
		
		$current_post = array (
	      'ID'           => $post_id,
	      'post_content' => $ppb_page_content,
	    );
	    
	    wp_update_post($current_post);
	    if (is_wp_error($post_id)) {
			$errors = $post_id->get_error_messages();
			foreach ($errors as $error) {
				echo esc_html($error);
			}
		}

		//re-hook this function
		add_action('save_post', 'photography_page_save_postdata');
	}

}

function photography_page_update_custom_meta($postID, $newvalue, $field_name) {

	if (isset($_POST['pp_meta_form'])) 
	{
		if (!get_post_meta($postID, $field_name)) {
			add_post_meta($postID, $field_name, $newvalue);
		} else {
			update_post_meta($postID, $field_name, $newvalue);
		}
	}

}

//init

add_action('admin_menu', 'photography_page_create_meta_box'); 
add_action('save_post', 'photography_page_save_postdata');  

/*
	End creating custom fields
*/

?>
